# -*- coding: utf-8 -*-

# Copyright (c) 2006 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a canvas item subclass for text.
"""

from PyQt4.QtCore import *
from PyQt4.QtGui import *

from E4CanvasItem import E4CanvasItem

class E4CanvasText(E4CanvasItem):
    """
    Class implementing a text canvas item subclass.
    """
    def __init__(self, canvas, origin = QPointF(0.0, 0.0), 
                 text = QString(), font = QFont()):
        """
        Constructor
        
        @param canvas reference to the canvas object (E4Canvas)
        @param origin origin of the rectangle (QPointF)
        @param text text for the text item (QString)
        @param font font for the text item (QFont)
        """
        E4CanvasItem.__init__(self, canvas, origin)
        
        self._text = text
        self._font = font
        
    def setFont(self, font):
        """
        Public method to set the font of the text item.
        
        @param font font to be set (QFont)
        """
        self._font = font
        
    def font(self):
        """
        Public method to get the font of the text item.
        
        @return reference to the font object (QFont)
        """
        return self._font
        
    def setText(self, text):
        """
        Public method to set the text of the text item.
        
        @param text text to be set (QString)
        """
        self._text = text
        
    def text(self):
        """
        Public method to get the text of the text item.
        
        @return reference to the text object (QString)
        """
        return self._text
        
    def drawShape(self, painter):
        """
        Public method to draw the shape.
        
        @param painter reference to the painter object (QPainter)
        """
        if not self.isVisible():
            return
        
        painter.setPen(self.getPen())
        painter.setBrush(self.getPen().brush())
        painter.setFont(self._font)
        fm = QFontMetricsF(self._font)
        painter.drawText(self.x(), self.y() + fm.ascent(), self._text)
        pbr = painter.boundingRect(QRectF(0.0, 0.0, 0.0, 0.0), 
                                   Qt.Alignment(Qt.AlignLeft), self._text)
        self._boundingRect = QRectF(self.x(), self.y(),
                                    pbr.width(), pbr.height())
        if self.isSelected():
            self.drawSelected(painter)
