# -*- coding: utf-8 -*-

# Copyright (c) 2004 - 2006 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing the UMLWidget base class.
"""

from PyQt4.QtCore import *
from PyQt4.QtGui import *

from E4Canvas.E4CanvasRectangle import E4CanvasRectangle

class UMLWidget(E4CanvasRectangle):
    """
    Class implementing the UMLWidget base class.
    """
    def __init__(self, canvas, x = 0, y = 0, rounded = False):
        """
        Constructor
        
        @param canvas canvas containing the class widget (QCanvas)
        @param x x-coordinate (integer)
        @param y y-coordinate (integer)
        @param rounded flag indicating a rounded corner (boolean)
        """
        E4CanvasRectangle.__init__(self, canvas)
        self.font = QApplication.font()
        self.font.setPointSize(10)
        self.margin = 5
        self.associations = []
        
        self.setSize(60, 30)
        
        if rounded:
            p = self.getPen()
            p.setCapStyle(Qt.RoundCap)
            p.setJoinStyle(Qt.RoundJoin)
        
        self.setX(x)
        self.setY(y)
        
        self.update()
        
    def addAssociation(self, assoc):
        """
        Method to add an association to this widget.
        
        @param assoc association to be added (AssociationWidget)
        """
        if assoc and not assoc in self.associations:
            self.associations.append(assoc)
        
    def removeAssociation(self, assoc):
        """
        Method to remove an association to this widget.
        
        @param assoc association to be removed (AssociationWidget)
        """
        if assoc and assoc in self.associations:
            self.associations.remove(assoc)
        
    def removeAssociations(self):
        """
        Method to remove all associations of this widget.
        """
        for assoc in self.associations[:]:
            assoc.unassociate()
            assoc.hide()
            del assoc
        
    def adjustAssociations(self):
        """
        Method to adjust the associations to widget movements.
        """
        for assoc in self.associations:
            assoc.widgetMoved()
        
    def moveBy(self, dx, dy):
        """
        Overriden method to move the widget relative.
        
        @param dx relative movement in x-direction (float)
        @param dy relative movement in y-direction (float)
        """
        E4CanvasRectangle.moveBy(self, dx, dy)
        self.adjustAssociations()
        
    def move(self, x, y):
        """
        Overriden method to move the widget absolute.
        
        @param dx absolute x-position (float)
        @param dy absolute y-position (float)
        """
        E4CanvasRectangle.move(self, x, y)
        self.adjustAssociations()
